@@ -151,7 +151,7 @@ def get_postgres_dump(dbname, ignore_permissions=False, file_name=None):
 
     :param file_name: optional file name for the dump. The file name should
         exclude any path. If file_name is ommitted, the dump will be written to
-        resources/sql/dumps/<dbname>->date>.dmp
+        fabgis_resources/sql/dumps/<dbname>->date>.dmp
         where date is in the form dd-mm-yyyy. This is the default naming
         convention used by the :func:`restore_postgres_dump` function below.
     :type file_name: str
@@ -171,13 +171,14 @@ def get_postgres_dump(dbname, ignore_permissions=False, file_name=None):
         extra_args = '-x -O'
 
     run('pg_dump %s -Fc -f /tmp/%s %s' % (extra_args, my_file, dbname))
-    get('/tmp/%s' % my_file, 'resources/sql/dumps/%s' % my_file)
+    get('/tmp/%s' % my_file, 'fabgis_resources/sql/dumps/%s' % my_file)
 
 
 @task
 def restore_postgres_dump(
         dbname,
         user=None,
+        password='',
         ignore_permissions=False,
         file_name=None):
     """Upload dump to host, remove existing db, recreate then restore dump.
@@ -190,13 +191,16 @@ def restore_postgres_dump(
         if needed.
     :type user: str
 
+    :param password: password to use for db connection - defaults to ''
+    :type password: str
+
     :param ignore_permissions: whether permissions in the restored dump
         should be retained.
     :type ignore_permissions: bool (default False)
 
     :param file_name: optional file name for the dump. If ommitted,
         the dump will be assumed to exist in
-        resources/sql/dumps/<dbname>->date>.dmp
+        fabgis_resources/sql/dumps/<dbname>->date>.dmp
         where date is in the form dd-mm-yyyy. This is the default naming
         convention used by the :func:`get_postgres_dump` function above.
     :type file_name: str
@@ -205,11 +209,11 @@ def restore_postgres_dump(
     if user is None:
         user = env.fg.user
     show_environment()
-    require_postgres_user(user)
+    require_postgres_user(user, password=password)
     if file_name is None or file_name == '':
         date = run('date +%d-%B-%Y')
         my_file = '%s-%s.dmp' % (dbname, date)
-        put('resources/sql/dumps/%s' % my_file, '/tmp/%s' % my_file)
+        put('fabgis_resources/sql/dumps/%s' % my_file, '/tmp/%s' % my_file)
     else:
         my_file = os.path.split(file_name)[1]
         put(file_name, '/tmp/%s' % my_file)
@@ -235,9 +239,9 @@ def restore_postgres_dump(
 def setup_nightly_backups():
     """Setup nightly backups for all postgresql databases.
 
-    The template script :file:`resources/server_config/cron/pg_backups` will
-    place the last 21 days of backups in the remote user's Dropbox directory
-    and will maintain 6 months of backups in their home directory.
+    The template script :file:`fabgis_resources/server_config/cron/pg_backups`
+    will place the last 21 days of backups in the remote user's Dropbox
+    directory and will maintain 6 months of backups in their home directory.
 
     .. seealso:: fabgis.dropbox for help on setting up dropbox on your server.
     """
@@ -251,7 +255,7 @@ def setup_nightly_backups():
         local_file = os.path.abspath(os.path.join(
             local_dir,
             '..',
-            'resources',
+            '../fabgis_resources',
             'server_config',
             'cron',
             'pg_backups.templ'))
